<div>
  <div class="testEditTitle"> 第<%= exercise_question.question_number%>题.(<%= exercise_question.question_score %>分)<br />
    <%= exercise_question.question_title %>
    <span class="ml10">(<%= convert_to_char(exercise_question.exercise_standard_answers.first.exercise_choice_id.to_s) %>)</span>
  </div>

  <%= link_to("", delete_exercise_question_exercise_index_path(:exercise_question => exercise_question.id, :quest_num => exercise_question.question_number),
              method: :delete, :confirm => l(:text_are_you_sure), :remote => true, :class => "ur_icon_de")  %>
  <a class="ur_icon_edit" title="编辑" onclick="pollQuestionEdit(<%= exercise_question.id%>);"></a>
  <a class='ur_icon_add' title='向下插入' id="add_mc_<%=exercise_question.id%>" onclick="dismiss('mc',<%=exercise_question.id%>);insert_MC('mc',<%=exercise_question.question_number%>,<%=exercise_question.id%>);"></a>
  <div class="cl"></div>
  <div class="ur_inputs">
    <table class="ur_table"  style="width:675px;">
      <tbody>
      <% exercise_question.exercise_choices.reorder("choice_position").each_with_index do |exercise_choice,index| %>
          <tr>
            <td>
              <label>
                <input class="ur_radio" type="radio" name="<%= exercise_question %>" value="<%= exercise_choice.choice_text%>" >
                <%= convert_to_char((index+1).to_s)%>&nbsp;&nbsp;<%= exercise_choice.choice_text%>
              </label>
            </td>
          </tr>
      <% end %>
      </tbody>
    </table>
  </div>
</div><!--单选题显示 end-->
<!-- 新增问题 -->
<div id="insert_new_poll_question_mc_<%=exercise_question.id%>">
</div>

<script type="text/javascript">
    function insert_MC(quest_type,quest_num,quest_id){
        var forms = $("form.new_exercise_question");
        if($.trim($("#insert_new_poll_question_"+quest_type+"_"+quest_id).html()) == "") {
            if(forms.length > 0){
                alert("请先保存正在编辑的题目再新建。");
            } else{
                <% score =exercise_question.question_score %>
                $("#insert_new_poll_question_"+quest_type+"_"+quest_id).html(
                                '<%= form_for(ExerciseQuestion.new,:html=>{:multipart=>true},:url=>create_exercise_question_exercise_path(exercise_question.exercise.id),:remote=>true) do |f|%>'+
                                ' <div class="questionContainer" style="width: 680px;"> '+
                                '<div class="ur_editor_title"> '+
                                '<label>问题：&nbsp;&nbsp;</label>'+
                                '<input type="hidden" name="quest_id" value="'+quest_id+'"/>'+
                                '<input type="hidden" name="quest_num" value="'+quest_num+'"/>'+
                                '<input type="hidden" name="question_type" value="1"/>'+
                                '<input name="question_title" id="poll_questions_title" class="questionTitle" placeholder="请输入单选题题目" type="text"/>'+
                                '</div>'+
                                '<div class="ur_editor_content">'+
                                '<ul>'+
                                '<li class="ur_item">'+
                                '<label>分数<span class="ur_index"></span>：&nbsp;&nbsp;&nbsp;</label>'+
                                '<input value="<%=score %>" id="question_score" type="text" name="question_score" style="width:40px; text-align:center; padding-left:0px;"/>分'+
                                '</li><div>'+
                                '<li class="ur_item">'+
                                '<label name="select_items" class="w56">选项A<span class="ur_index"></span>：&nbsp;&nbsp;&nbsp;</label>'+
                                '<input maxlength="200" type="text" name="question_answer[0]" placeholder="输入选项内容"/>'+
                                '<a class="icon_add" title="向下插入选项" onclick="add_single_answer($(this));"></a>'+
                                '<a class="icon_remove"  title="删除" onclick="remove_single_answer($(this))"></a>'+
                                '</li>'+
                                '<div class="cl"></div>'+
                                '<li class="ur_item">'+
                                '<label name="select_items" class="w56">选项B<span class="ur_index"></span>：&nbsp;&nbsp;&nbsp;</label>'+
                                '<input maxlength="200" type="text" name="question_answer[1]" placeholder="输入选项内容"/>'+
                                '<a class="icon_add" title="向下插入选项" onclick="add_single_answer($(this));"></a>'+
                                '<a class="icon_remove"  title="删除" onclick="remove_single_answer($(this))"></a>'+
                                '</li>'+
                                '<div class="cl"></div>'+
                                '<li class="ur_item">'+
                                '<label name="select_items" class="w56">选项C<span class="ur_index"></span>：&nbsp;&nbsp;&nbsp;</label>'+
                                '<input maxlength="200" type="text" name="question_answer[2]" placeholder="输入选项内容"/>'+
                                '<a class="icon_add" title="向下插入选项" onclick="add_single_answer($(this));"></a>'+
                                '<a class="icon_remove" title="删除" onclick="remove_single_answer($(this))"></a>'+
                                '</li>'+
                                '<div class="cl"></div>'+
                                '<li class="ur_item">'+
                                '<label name="select_items" class="w56">选项D<span class="ur_index"></span>：&nbsp;&nbsp;&nbsp;</label>'+
                                '<input maxlength="200" type="text" name="question_answer[3]" placeholder="输入选项内容"/>'+
                                '<a class="icon_add" title="向下插入选项" onclick="add_single_answer($(this));"></a>'+
                                '<a class="icon_remove" title="删除" onclick="remove_single_answer($(this))"></a>'+
                                '</li></div>'+
                                '<div class="cl"></div>'+
                                '<li class="ur_item">'+
                                '<label>标准答案<span class="ur_index"></span>：&nbsp;&nbsp;&nbsp;</label>'+
                                '<input name="exercise_choice" id="question_standard_ans" placeholder="若标准答案为A，在此输入A即可" type="text">'+
                                '</li>'+
                                '<div class="cl"></div>'+
                                '</ul>'+
                                '</div>'+
                                '<div class="ur_editor_footer">'+
                                '<a class="btn btn_dark btn_submit c_white" data-button="ok" id="add_new_question">'+
                                '保存'+
                                '</a>'+
                                '<a class="btn btn_light btn_cancel" data-button="cancel" onclick="$(this).parent().parent().parent().remove();">'+
                                '<%= l(:button_cancel)%>'+
                                '</a>'+
                                '</div>'+
                                '<div class="cl"></div>'+
                                '</div>'+
                                '<% end%>'
                );
                $("#poll_questions_title").focus();
                $("#add_new_question").one('click', function(){
                    add_poll_question($(this),1);
                });
                }
       }
        else {
            $("#insert_new_poll_question_"+quest_type+"_"+quest_id).html("");
        }
    }
</script>